import axios from 'axios';

export interface DeviceRecord {
  size: number;
  current: number;
  name?: string;
  clientId?: number;
  productId?: number;
  status?: string;
  isOnline?: boolean;
  pageable?: string;
  longitude?: number;
  latitude?: number;
  icon?: string;
  hardwareVersion?: string;
  firmwareVersion?: string;
  productName?: string;
  id?: number;
}

export interface DeviceCreateRecord {
  num?: number;
  prefix?: string;
  name?: string;
  hardwareVersion: string;
  firmwareVersion: string;
  extendParams: string[];
  properties: string;
  productId: number;
}

export interface DeviceUpdateRecord extends DeviceCreateRecord {
  id: number;
}

export interface DeviceEventRecord {
  id: number;
  clientId: number;
  serveName: string;
  params: string;
}


// 分页查询
export function queryDeviceList(data: DeviceRecord) {
  return axios({
    url: '/api/rest/device',
    method: 'get',
    params: data,
  });
}

// 名称模糊查询
export function queryDeviceByNameList(data: any) {
  return axios({
    url: `/api/rest/device/list`,
    method: 'get',
    params: data,
  });
}

// 查看详情
export function queryDeviceDetail(id: number) {
  return axios.get(`/api/rest/device/${id}`);
}
// 名称模糊查询
export function queryProductByName(data: any) {
  return axios({
    url: `/api/rest/product/fuzzy`,
    method: 'get',
    params: data,
  });
}

// 设备状态
export function toggleDeviceStatus(id: number) {
  return axios.patch(`/api/rest/device/toggle/${id}`)
}

// 新增
export function createDevice(data: DeviceCreateRecord) {
  return axios.post(`/api/rest/device`, data);
}

// 编辑
export function updateDevice(data: DeviceUpdateRecord) {
  return axios.patch(`/api/rest/device/${data.id}`, data);
}
// 删除
export function deleteDevice(id: number) {
  return axios.delete(`/api/rest/device/${id}`);
}

// 查询上报
export function queryDeviceRecord(data: DeviceRecord) {
  return axios({
    url: `/api/rest/device/record/data`,
    method: 'get',
    params: data,
  });
}

// 执行服务列表
export function queryDeviceServeList(data: DeviceRecord) {
  return axios({
    url: `/api/rest/device/serve`,
    method: 'get',
    params: data,
  });
}

// 批量创建
export function createDeviceBatch(data: DeviceCreateRecord) {
  return axios.post(`/api/rest/device/batch`, data);
}

// 手动触发事件
export function triggerEvent(data: DeviceEventRecord) {
  return axios({
    url: `/api/rest/device/event`,
    method: 'post',
    data,
  });
}

// 下发命令
export function sendCommand(data: any) {
  const { deviceId, qos, ...rest } = data;
  return axios({
    url: `/api/rest/device/send`,
    method: 'post',
    params: {
      deviceId,
      qos,
    },
    data: rest,
  });
}


